@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20181218';
+our $VERSION = '5.20190120';
 our %utilities;
 
 sub utilities {
@@ -1459,6 +1459,13 @@ my %delta = (
         removed => {
         }
     },
+    5.029007 => {
+        delta_from => 5.029006,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
